The top level :mod:`matplotlib` module
======================================


.. py:currentmodule:: matplotlib

.. autofunction:: use

.. autofunction:: get_backend

.. py:data:: rcParams

    An instance of :class:`RcParams` for handling default matplotlib values.

.. autofunction:: rc

.. autofunction::rcdefaults

.. autofunction::rc_file

.. autofunction::rc_context

.. autofunction:: matplotlib_fname

.. autofunction::rc_file_defaults

.. autofunction::interactive

.. autofunction::is_interactive

.. autoclass:: RcParams

.. autofunction:: rc_params

.. autofunction:: rc_params_from_file

.. autoclass:: rc_context
